#!/usr/bin/env python3
"""
@author: Quentin Rodier
Creation : 07/01/2021

Last modifications
"""

import matplotlib as mpl
mpl.use('Agg')
from read_MNHfile import read_netcdf
from Panel_Plot import PanelPlot
import cartopy.crs as ccrs
import numpy as np
import os
import cartopy.io.shapereader as shpreader

os.system('rm -f tempgraph*')
#
#  User's parameter / Namelist
#
path="../010_run/"
LnameFiles = ['PAN_00.2.SEG01.004.nc', 'PAN_00.2.SEG01.008.nc', 'PAN_00.2.SEG01.012.nc', 'PAN_00.2.SEG01.016.nc', 'PAN_00.2.SEG01.020.nc', 'PAN_00.2.SEG01.024.nc']

Dvar_input = {'f'+str(i):['T2M', 'TSRAD', 'HU2M','SWD','LWD','UT', 'CLDFR', 'TKET','WT', 'H','LE','level', 'longitude','latitude','time']
              for i in range(1,7)}


#  Read the variables in the files
Dvar = {}
Dvar = read_netcdf(LnameFiles, Dvar_input, path=path, removeHALO=True)

# Departements francais
departements_shp='departements-20180101.shp'
adm1_shapes = list(shpreader.Reader(departements_shp).geometries())

titlepad=25
minmaxpad=1.04
timepad=-0.10
colorbarpad=0.01
labelcolorbarpad = 13
colorbaraspect=20

################################################################
#########          PANEL 1  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'H', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['H'][:,:] for i in range(1,7)]
Lcbarlabel = ['W/m2']*len(Lplot)
Lminval = [-100]*len(Lplot)
Lmaxval = [1000]*len(Lplot)
Lstep = [25]*len(Lplot)
Lstepticks = [100]*len(Lplot)
Lfacconv = [1]*len(Lplot)
Lcolormap = ['rainbow']*len(Lplot)
Ltime = [Dvar['f'+str(i)]['time']/3600.0 for i in range(1,7)]
LaddWhite_cm = [True]*len(Lplot)
LaxeX = [Dvar['f1']['longitude']]*len(Lplot)
LaxeY = [Dvar['f1']['latitude']]*len(Lplot)
Ltitle = ['']*len(Lplot)
Lxlab = ['longitude']*len(Lplot)
Lylab = ['latitude']*len(Lplot)
Lpltype = ['cf']*len(Lplot)
Lprojection = [ccrs.PlateCarree()]*len(Lplot)

fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection, gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(1, fig)

################################################################
#########          PANEL 2  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'LE', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['LE'][:,:] for i in range(1,7)]
Lcbarlabel = ['W/m2']*len(Lplot)
Lminval = [0]*len(Lplot)
Lmaxval = [600]*len(Lplot)
Lstep = [25]*len(Lplot)
Lstepticks = [100]*len(Lplot)
Lfacconv = [1]*len(Lplot)
Lcolormap = ['rainbow']*len(Lplot)
LaddWhite_cm = [True]*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(2, fig)


################################################################
#########          PANEL 3  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'T2M', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['T2M'][:,:]-273.15 for i in range(1,7)]
Lcbarlabel = ['°C']*len(Lplot)
Lminval = [10]*len(Lplot)
Lmaxval = [30]*len(Lplot)
Lstep = [0.5]*len(Lplot)
Lstepticks = [2.5]*len(Lplot)
Lfacconv = [1]*len(Lplot)
Lcolormap = ['rainbow']*len(Lplot)
LaddWhite_cm = [False]*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(3, fig)


################################################################
#########          PANEL 4  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'HU2M', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['HU2M'][:,:]*100.0 for i in range(1,7)]
Lcbarlabel = ['%']*len(Lplot)
Lminval = [10]*len(Lplot)
Lmaxval = [100]*len(Lplot)
Lstep = [2]*len(Lplot)
Lstepticks = [10]*len(Lplot)
Lfacconv = [1]*len(Lplot)
Lcolormap = ['rainbow_r']*len(Lplot)
LaddWhite_cm = [False]*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(4, fig)


################################################################
#########          PANEL 5  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'TSRAD', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['TSRAD'][:,:]-273.15 for i in range(1,7)]
Lcbarlabel = ['°C']*len(Lplot)
Lminval = [10]*len(Lplot)
Lmaxval = [50]*len(Lplot)
Lstep = [0.5]*len(Lplot)
Lstepticks = [5]*len(Lplot)
Lfacconv = [1]*len(Lplot)
Lcolormap = ['rainbow']*len(Lplot)
LaddWhite_cm = [False]*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(5, fig)


################################################################
#########          PANEL 6  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'SWD', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['SWD'][:,:] for i in range(1,7)]
Lcbarlabel = ['W/m2']*len(Lplot)
Lminval = [0]*len(Lplot)
Lmaxval = [800]*len(Lplot)
Lstep = [25]*len(Lplot)
Lstepticks = [100]*len(Lplot)
Lfacconv = [1]*len(Lplot)
Lcolormap = ['binary']*len(Lplot)
LaddWhite_cm = [True]*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='grey', facecolor='white', alpha=0.1)
Panel1.save_graph(6, fig)


################################################################
#########          PANEL 7  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'LWD', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['LWD'][:,:] for i in range(1,7)]
Lcbarlabel = ['W/m2']*len(Lplot)
Lminval = [280]*len(Lplot)
Lmaxval = [440]*len(Lplot)
Lstep = [2.5]*len(Lplot)
Lstepticks = [50]*len(Lplot)
Lfacconv = [1]*len(Lplot)
Lcolormap = ['binary_r']*len(Lplot)
LaddWhite_cm = [False]*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(7, fig)

################################################################
#########          PANEL 8  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'W (k=20) 500m', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['WT'][20,:,:] for i in range(1,7)]
Lcbarlabel = ['m/s']*len(Lplot)
Lminval = [-5]*len(Lplot)
Lmaxval = [5]*len(Lplot)
Lstep = [0.1]*len(Lplot)
Lstepticks = [1]*len(Lplot)
Lcolormap = ['seismic']*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(8, fig)

################################################################
#########          PANEL 9  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'W (k=27) 1500m', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['WT'][27,:,:] for i in range(1,7)]
Lcbarlabel = ['m/s']*len(Lplot)
Lminval = [-5]*len(Lplot)
Lmaxval = [5]*len(Lplot)
Lstep = [0.1]*len(Lplot)
Lstepticks = [1]*len(Lplot)
Lcolormap = ['seismic']*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(9, fig)


################################################################
#########          PANEL 10  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'CLDFR 500m', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['CLDFR'][20,:,:] for i in range(1,7)]
Lcbarlabel = ['-']*len(Lplot)
Lminval = [0]*len(Lplot)
Lmaxval = [1]*len(Lplot)
Lstep = [0.025]*len(Lplot)
Lstepticks = [0.2]*len(Lplot)
Lcolormap = ['binary_r']*len(Lplot)
LaddWhite_cm = [False]*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='white', facecolor='white', alpha=0.1)
Panel1.save_graph(10, fig)

################################################################
#########          PANEL 11  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'CLDFR 1500m', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['CLDFR'][27,:,:] for i in range(1,7)]
Lcbarlabel = ['-']*len(Lplot)
Lminval = [0]*len(Lplot)
Lmaxval = [1]*len(Lplot)
Lstep = [0.025]*len(Lplot)
Lstepticks = [0.2]*len(Lplot)
Lcolormap = ['binary_r']*len(Lplot)
LaddWhite_cm = [False]*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='white', facecolor='white', alpha=0.1)
Panel1.save_graph(11, fig)

################################################################
#########          PANEL 12  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'CLDFR 10000m', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['CLDFR'][53,:,:] for i in range(1,7)]
Lcbarlabel = ['-']*len(Lplot)
Lminval = [0]*len(Lplot)
Lmaxval = [1]*len(Lplot)
Lstep = [0.025]*len(Lplot)
Lstepticks = [0.2]*len(Lplot)
Lcolormap = ['binary_r']*len(Lplot)
LaddWhite_cm = [False]*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='white', facecolor='white', alpha=0.1)
Panel1.save_graph(12, fig)


################################################################
#########          PANEL 13  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'TKET k=20, 500m', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['TKET'][20,:,:] for i in range(1,7)]
Lcbarlabel = ['m2/s2']*len(Lplot)
Lminval = [0]*len(Lplot)
Lmaxval = [2]*len(Lplot)
Lstep = [0.1]*len(Lplot)
Lstepticks = [1]*len(Lplot)
Lcolormap = ['binary']*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(13, fig)
################################################################
#########          PANEL 14  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'TKET k=27, 1500m', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['TKET'][27,:,:] for i in range(1,7)]
Lcbarlabel = ['m2/s2']*len(Lplot)
Lminval = [0]*len(Lplot)
Lmaxval = [2]*len(Lplot)
Lstep = [0.1]*len(Lplot)
Lstepticks = [1]*len(Lplot)
Lcolormap = ['binary']*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval, 
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv, 
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(14, fig)

################################################################
#########          PANEL 15  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'U k=2, 6m', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['UT'][2,:,:] for i in range(1,7)]
Lcbarlabel = ['m/s']*len(Lplot)
Lminval = [-2]*len(Lplot)
Lmaxval = [20]*len(Lplot)
Lstep = [0.1]*len(Lplot)
Lstepticks = [2.5]*len(Lplot)
Lcolormap = ['twilight']*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval,
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv,
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(15, fig)
################################################################
#########          PANEL 16  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'U k=27, 1500m', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['UT'][27,:,:] for i in range(1,7)]
Lcbarlabel = ['m/s']*len(Lplot)
Lminval = [-2]*len(Lplot)
Lmaxval = [20]*len(Lplot)
Lstep = [0.1]*len(Lplot)
Lstepticks = [2.5]*len(Lplot)
Lcolormap = ['twilight']*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval,
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv,
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(16, fig)

################################################################
#########          PANEL 17  # 
###############################################################
Panel1 = PanelPlot(2,3, [25,14],'U k=53, 10000m', titlepad=titlepad, minmaxpad=minmaxpad, timepad=timepad, colorbarpad=colorbarpad, labelcolorbarpad = labelcolorbarpad , colorbaraspect=colorbaraspect)
Lplot = [ Dvar['f'+str(i)]['UT'][53,:,:] for i in range(1,7)]
Lcbarlabel = ['m/s']*len(Lplot)
Lminval = [10]*len(Lplot)
Lmaxval = [40]*len(Lplot)
Lstep = [0.1]*len(Lplot)
Lstepticks = [5]*len(Lplot)
Lcolormap = ['twilight']*len(Lplot)
fig = Panel1.psectionH(lon=LaxeX, lat=LaxeY, Lvar=Lplot, Lxlab=Lxlab, Lylab=Lylab, Ltitle=Ltitle, Lminval=Lminval, Lmaxval=Lmaxval,
                                Lstep=Lstep, Lstepticks=Lstepticks, Lcolormap=Lcolormap, Lcbarlabel=Lcbarlabel, Lfacconv=Lfacconv,
                                colorbar=True, Ltime=Ltime, LaddWhite_cm=LaddWhite_cm, Lproj=Lprojection,gridLines=False)
for i in range(6):
  fig.axes[i*2].add_geometries(adm1_shapes, ccrs.PlateCarree(),edgecolor='black', facecolor='gray', alpha=0.1)
Panel1.save_graph(17, fig)
